aboutsummaryrefslogtreecommitdiffstats
path: root/include/asterisk/parking.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/asterisk/parking.h')
-rwxr-xr-xinclude/asterisk/parking.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/include/asterisk/parking.h b/include/asterisk/parking.h
index 1434c5c3a..24bb6826f 100755
--- a/include/asterisk/parking.h
+++ b/include/asterisk/parking.h
@@ -1,7 +1,7 @@
/*
* Asterisk -- A telephony toolkit for Linux.
*
* Call Parking API
*
* Copyright (C) 1999, Mark Spencer
*
@@ -42,10 +42,15 @@ extern int ast_masq_park_call(struct ast_channel *rchan, struct ast_channel *hos
/*! Returns the call parking extension for drivers that provide special
call parking help */
extern char *ast_parking_ext(void);
+extern char *ast_pickup_ext(void);
//! Bridge a call, optionally allowing redirection
extern int ast_bridge_call(struct ast_channel *chan, struct ast_channel *peer, int allowredirect, int allowdisconnect);
+extern unsigned int ast_get_group(char *s);
+
+extern int ast_pickup_call(struct ast_channel *chan);
+
#endif /* _PARKING_H */
@@ -1,7 +1,7 @@
* Asterisk -- A telephony toolkit for Linux.
*
- * Call Parking API
+ * Call Parking and Pickup API
*
* Copyright (C) 1999, Mark Spencer